#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:		qubes-kernel-vm-support
Version:	4.0.33
Release:	1%{?dist}
Summary:	Qubes VM kernel and initramfs modules
Source0:    qubes-utils-%{version}.tar.gz

Group:		Qubes
Vendor:     Invisible Things Lab
License:	GPL v2 only
URL:		http://www.qubes-os.org

Requires:	dracut
Requires:	dkms
BuildRequires:  make

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

2. u2mfn kernel module sources (dkms) required by GUI agent and R2 version of
libvchan library.

%prep
%setup -q -n qubes-utils-%{version}

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/src/u2mfn-%{version}/
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%post
dkms add -m u2mfn -v %{version} --rpm_safe_upgrade

%preun
dkms remove -m u2mfn -v %{version} --all --rpm_safe_upgrade

if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Thu May 13 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Thu May 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9b7bfab
- version 4.0.33

* Thu May 13 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3949f95
- kernel-vm-support: add make as BR

* Thu May 13 2021 Shawn Anastasio <shawn@anastas.io> - ac2ccf5
- Makefile: remove broken 32-bit host check

* Wed Mar 17 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 44dfa9d
- version 4.0.32

* Wed Mar 17 2021 Paweł Marczewski <pawel@invisiblethingslab.com> - 889d427
- Drop Python 2 support

* Tue Mar 16 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d0d93bb
- Revert "debian: drop python2 on bullseye"

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 45d9d6b
- Validate remote filename before displaying it

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 6ca99d5
- Modernize systemd unit files

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - c4a9fef
- Meminfo writer comes before user logins

* Fri Jan 08 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 02063ae
- Fix some links to more modern versions

* Fri Jan 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bbe4938
- debian: update compat

* Fri Jan 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - d4d3519
- debian: update control

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e33b810
- ci: add coverage

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d6089bb
- gitlab-ci: add custom jobs

* Fri Jan 08 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - db6ca35
- Add .gitlab-ci.yml

* Sun Oct 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 97271ba
- version 4.0.31

* Sat Oct 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fea53c2
- makefile: use 'python2' explicitly when needed, instead of just 'python'

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2ac71a2
- debian: don't fail package install on missing /var/lib/qubes

* Thu Oct 22 2020 Rusty Bird <rustybird@net-c.com> - 24642e4
- imgconverter: make output reproducible by omitting timestamps

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f3d01f3
- dracut: remove useless use of basename

* Sun Jul 05 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4219f12
- version 4.0.30

* Sun Jul 05 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 78945b3
- travis: update config

* Sun Jul 05 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b3cc13a
- debian: drop python2 on bullseye

* Thu Jul 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6a1ee1e
- version 4.0.29

* Tue Jun 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 99d87c2
- debian: add Provides: python3-qubesimgconverter

* Tue Mar 17 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b8bdbcf
- version 4.0.28

* Mon Mar 16 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 28cc271
- qubesimgconverter: include Python 3 version in Debian package

* Mon Mar 16 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 1706694
- Image.get_through_dvm: support Python 3

* Wed Mar 11 2020 Ilpo Järvinen <ilpo.jarvinen@cs.helsinki.fi> - 46b7ae7
- Get virt_to_phys from header

* Wed Mar 11 2020 Ilpo Järvinen <ilpo.jarvinen@cs.helsinki.fi> - 1a18aa9
- Use proc_ops instead of file_operations on 5.6 kernels

* Fri Jan 31 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - facdf4d
- version 4.0.27

* Sun Dec 29 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ffdc3e5
- debian: fix dependencies of qubes-kernel-vm-support pkg

* Sat Dec 28 2019 Patrick Schleizer <adrelanos@riseup.net> - 2716a39
- qubes-kernel-vm-support.postinst run update-grub

* Sat Dec 28 2019 Patrick Schleizer <adrelanos@riseup.net> - 3ed9157
- qubes-kernel-vm-support.preinst create folder /boot/grub

* Sat Dec 28 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ea43382
- travis: update python versions

* Sat Dec 28 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 4068ac8
- travis: switch to bionic

* Sat Sep 28 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c2beb17
- version 4.0.26

* Sat Sep 28 2019 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - ac13973
- partition full volatile for non-COW setups too

* Sat Sep 28 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 484f67a
- Disable BLS config style in grub

* Fri Sep 20 2019 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - 4a28ab6
- align volatile swap partition to 1Mb instead of 512b

* Tue Sep 17 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ff7f658
- rpm: update python2 deps

* Sat Aug 17 2019 M. Vefa Bicakci <m.v.b@runbox.com> - 5a83961
- u2mfn: Make compatible with kernel versions >= 5.3.y

* Mon Jun 10 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 425f7f4
- version 4.0.25

* Mon Jun 10 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6501b26
- initrd: mount / rw for the overlayfs setup time

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 042b671
- version 4.0.24

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9c6c825
- initramfs: use overlayfs for /lib/modules, if available

* Wed Jun 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e7c90c7
- Declare u2mfn module version, skip build for qubes kernels

* Wed Jun 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f365d7c
- travis: remove older Fedora releases and add Fedora 30

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2b84113
- travis: switch to xenial

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e00a64a
- python3: use macro pkgversion

